gene_chromosome_data: Data containing chromosome information and the genes located on them.
Description
A dataset containing the chromosome information of the gene expression and methylation array data to be analysed.
Usage
data(gene_chromosome_data)
Format
A data frame with 20 rows and 2 columns.
Details
The dataset contains the information of chromosomes 1 AND 2 and the genes located on them.
See Also
gene_expression_data
methylation_data